Examples
========

Whilst there are many specific ways to use the IMNN depending on the size of the dataset and speed at which a simulation can be generated, the easiest way to interact with the IMNN is via :func:`~imnn.IMNN` described at the end of this page

.. toctree::
   :maxdepth: 2
   :caption: Here are a few examples of the IMNN being used:

   examples/subclasses
   examples/lfi
   examples/2d_field_inference/2d_field_inference
   examples/additive_noise/additive_noise
   examples/imnn_vs_regression/imnn_vs_regression


IMNN
----
.. autofunction:: imnn.IMNN
